pub struct DnaBytes(pub Vec<u8>);Expand description
A newtype wrapper around a Vec<u8> with implementations
of the Mer and Vmer traits.
Tuple Fields
0: Vec<u8>Trait Implementations
Sourceimpl Mer for DnaBytes
impl Mer for DnaBytes
Sourceimpl Ord for DnaBytes
impl Ord for DnaBytes
Sourceimpl PartialOrd for DnaBytes
impl PartialOrd for DnaBytes
Sourceimpl Vmer for DnaBytes
impl Vmer for DnaBytes
Sourcefn from_slice(seq: &[u8]) -> Self
fn from_slice(seq: &[u8]) -> Self
Create a Vmer from a sequence of bytes
Sourcefn first_kmer<K: Kmer>(&self) -> K
fn first_kmer<K: Kmer>(&self) -> K
Get the first Kmer from the sequence
Sourcefn both_term_kmer<K: Kmer>(&self) -> (K, K)
fn both_term_kmer<K: Kmer>(&self) -> (K, K)
Get the terminal kmer of the sequence, on the both side of the sequence
Sourcefn term_kmer<K: Kmer>(&self, dir: Dir) -> K
fn term_kmer<K: Kmer>(&self, dir: Dir) -> K
Get the terminal kmer of the sequence, on the side of the sequence given by dir
Sourcefn iter_kmers<K: Kmer>(&self) -> KmerIter<'_, K, Self> ⓘ
fn iter_kmers<K: Kmer>(&self) -> KmerIter<'_, K, Self> ⓘ
Iterate over the kmers in the sequence
Sourcefn iter_kmer_exts<K: Kmer>(&self, seq_exts: Exts) -> KmerExtsIter<'_, K, Self> ⓘ
fn iter_kmer_exts<K: Kmer>(&self, seq_exts: Exts) -> KmerExtsIter<'_, K, Self> ⓘ
Iterate over the kmers and their extensions, given the extensions of the whole sequence
impl Eq for DnaBytes
impl StructuralPartialEq for DnaBytes