pub struct DnaSlice<'a>(pub &'a [u8]);Expand description
A newtype wrapper around a &[u8] with implementations
of the Mer and Vmer traits.
Tuple Fields
0: &'a [u8]Trait Implementations
Sourceimpl Mer for DnaSlice<'_>
impl Mer for DnaSlice<'_>
Sourceimpl<'a> Ord for DnaSlice<'a>
impl<'a> Ord for DnaSlice<'a>
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a> PartialOrd for DnaSlice<'a>
impl<'a> PartialOrd for DnaSlice<'a>
Sourceimpl Vmer for DnaSlice<'_>
impl Vmer for DnaSlice<'_>
Sourcefn from_slice(seq: &[u8]) -> Self
fn from_slice(seq: &[u8]) -> Self
Create a Vmer from a sequence of bytes
Sourcefn first_kmer<K: Kmer>(&self) -> K
fn first_kmer<K: Kmer>(&self) -> K
Get the first Kmer from the sequence
Sourcefn both_term_kmer<K: Kmer>(&self) -> (K, K)
fn both_term_kmer<K: Kmer>(&self) -> (K, K)
Get the terminal kmer of the sequence, on the both side of the sequence
Sourcefn term_kmer<K: Kmer>(&self, dir: Dir) -> K
fn term_kmer<K: Kmer>(&self, dir: Dir) -> K
Get the terminal kmer of the sequence, on the side of the sequence given by dir
Sourcefn iter_kmers<K: Kmer>(&self) -> KmerIter<'_, K, Self> ⓘ
fn iter_kmers<K: Kmer>(&self) -> KmerIter<'_, K, Self> ⓘ
Iterate over the kmers in the sequence
Sourcefn iter_kmer_exts<K: Kmer>(&self, seq_exts: Exts) -> KmerExtsIter<'_, K, Self> ⓘ
fn iter_kmer_exts<K: Kmer>(&self, seq_exts: Exts) -> KmerExtsIter<'_, K, Self> ⓘ
Iterate over the kmers and their extensions, given the extensions of the whole sequence
impl<'a> Eq for DnaSlice<'a>
impl<'a> StructuralPartialEq for DnaSlice<'a>