Exts

Struct Exts 

pub struct Exts {
    pub val: u8,
}
Store single-base extensions for a DNA Debruijn graph.

8 bits, 4 higher order ones represent extensions to the right, 4 lower order ones represent extensions to the left. For each direction the bits (from lower order to higher order) represent whether there exists an extension with each of the letters A, C, G, T. So overall the bits are: right left T G C A T G C A

Fields

val: u8

Implementations

Source

impl Exts

pub fn new(val: u8) -> Self

pub fn empty() -> Exts

pub fn from_single_dirs(left: Exts, right: Exts) -> Exts

pub fn merge(left: Exts, right: Exts) -> Exts

pub fn add(&self, v: Exts) -> Exts

pub fn subtract(&self, v: Exts) -> Exts

subtract an Exts from an Exts

pub fn set(&self, dir: Dir, pos: u8) -> Exts

pub fn remove(&self, dir: Dir, pos: u8) -> Exts

pub fn get(&self, dir: Dir) -> Vec<u8>

pub fn has_ext(&self, dir: Dir, base: u8) -> bool

pub fn from_slice_bounds(src: &[u8], start: usize, length: usize) -> Exts

pub fn from_dna_string(src: &DnaString, start: usize, length: usize) -> Exts

pub fn num_exts_l(&self) -> u8

pub fn num_exts_r(&self) -> u8

pub fn num_ext_dir(&self, dir: Dir) -> u8

pub fn mk_left(base: u8) -> Exts

pub fn mk_right(base: u8) -> Exts

pub fn mk(left_base: u8, right_base: u8) -> Exts

pub fn get_unique_extension(&self, dir: Dir) -> Option<u8>

pub fn single_dir(&self, dir: Dir) -> Exts

pub fn complement(&self) -> Exts

Complement the extension bases for each direction

pub fn reverse(&self) -> Exts

pub fn rc(&self) -> Exts