pub struct Tags {
pub val: Marker,
}Expand description
Compress up to 64 tags to one u64 (8 bytes) (or up to 128 tags to a
u128(16 bytes) with the feature sample128 enabled)
Fields
val: MarkerImplementations
Sourceimpl Tags
impl Tags
Sourcepub fn new(val: Marker) -> Self
pub fn new(val: Marker) -> Self
Make a new Tags from a u64 (or u128 with the feature sample128 enabled)
Sourcepub fn from_tag_vec(vec: &Vec<Tag>) -> Self
pub fn from_tag_vec(vec: &Vec<Tag>) -> Self
encodes a sorted (!) Vec
pub fn to_tag_vec(&self) -> Vec<Tag> ⓘ
pub fn to_string_vec<'a>( &'a self, str_map: &'a BiMap<String, Tag>, ) -> Vec<&'a str>
Sourcepub fn bit_and(&self, marker: Marker) -> bool
pub fn bit_and(&self, marker: Marker) -> bool
compares the value of the tags with another value (marker) with a bit-wise and,
returns true if the result is greater than 0:
00101 & 01000 -> false
00101 & 00100 -> true
Sourcepub fn bit_and_dist(&self, marker: Marker) -> usize
pub fn bit_and_dist(&self, marker: Marker) -> usize
compares the value of the tags with another value (marker) with a bit-wise and
counts the overlaps:
00101 & 01000 -> 0
00101 & 00100 -> 1
00101 & 00101 -> 2
Sourcepub fn iter(&self) -> TagsIterator ⓘ
pub fn iter(&self) -> TagsIterator ⓘ
get an iterator over the tags in the Tags